@@ -3,10 +3,10 @@ var html_string = '<svg style="width:100%;height:400px"></svg>';
 var html_string_analytics = '<svg style="width:100%;height:100%"></svg>';
 var chart_scripts = {};
 
-function loadChart(data, graph_key){
+function loadChart(data, graph_key, reload){
    function storeToChartScripts(data_str) {
-      $('body').removeClass("loading");
-      return function(data, textStatus, jqXHR) {
+      return function(f_data, textStatus, jqXHR) {
+            data.removeClass("loading");
             console.log("call " + data_str);
             chart_scripts[data_str] = loadChartScript;
       };
@@ -14,20 +14,24 @@ function loadChart(data, graph_key){
 
    data_str = data.serialize();
 
-   if(data_str in chart_scripts){
-      $('body').removeClass("loading");
+   if(!reload && data_str in chart_scripts){
+      data.removeClass("loading");
       console.log("run " + data_str);
       chart_scripts[data_str]();
    } else {
       url = "{% url 'chart-data' %}" + graph_key + "/";
+      if(reload)
+         reload_str = "&" + reload + "=true"
+      else
+         reload_str = ""
       $.ajax({
          dataType: "script",
          'url': url,
-         'data': data.serialize(),
+         'data': data_str + reload_str,
          success: storeToChartScripts(data_str),
          error: function(){
              alert("Error during chart loading.");
-             $('body').removeClass("loading");
+             data.removeClass("loading");
          }
       });
    };
@@ -42,34 +46,37 @@ function defer(method) {
 }
 
 function loadAnchor(){
-   $('body').addClass("loading");
+   if($(this)[0].id == 'reload' || $(this)[0].id == 'reload_all')
+      reload = $(this)[0].id;
+   else
+      reload = false;
    var data = $(this).closest('form.stateform');
+   data.addClass("loading");
    var graph_key = data.find(".hidden_graph_key").first().val();
    var is_analytics = $(this).parent().hasClass("chrt_flex");
    if($(this).hasClass('select_box_chart_type') || $(this).hasClass('stateform')){
       $("#chart_container_" + graph_key).empty().append(is_analytics ? html_string_analytics : html_string);
    };
-   loadChart(data, graph_key);
+   loadChart(data, graph_key, reload);
 }
 
 function loadAnalyticsChart(chart_key){
    $('body').addClass("loading");
    $('.admin_charts').hide();
    $("#chart_element_" + chart_key + ".notloaded").load("/admin_tools_stats/analytics/chart/" + chart_key, function(){
-      $(this).removeClass('notloaded')
-      $(this).addClass('loaded')
+      $(this).removeClass('notloaded');
+      $(this).addClass('loaded');
       $(this).find('form.stateform:visible').each(loadAnchor);
-   });
-   $("#chart_element_" + chart_key).each(function(){
-      $('#chart_element_' + $(this).data("chart-key")).show();
       $('body').removeClass("loading");
    });
+   $("#chart_element_" + chart_key).show();
 }
 
 defer( function(){
    $( document ).ready(function() {
 
-      $('body').on('change', '.chart-input', loadAnchor);
+      $('body').on('change', '#load_on_change:checked ~ .chart-input', loadAnchor);
+      $('body').on('click', '.reload', loadAnchor);
       $('form.stateform:visible').each(loadAnchor);
    });
 });
